Module model

Module model 

Components that form an AssemblageDB view.

All of the structs in this module are meant to be serializable to/from JSON (or any other serde-supported format) and act as the interface exchange format between frontends and AssemblageDB backends.

See the crate’s main docs for more details.

Structs

Lineage
A link to another node which may include a line of ancestors that show the descendant’s context.
PreviewLink
A link to another node together with the first block of that node as a preview.
Section
A group of descendant blocks of the viewed node (or the node itself if it is atomic).
Space
A single top-level view that displays multiple nodes side by side as tiles.
Subsection
A descendant block of a section together with its branches (before and after the block).
Tile
A high level, linearized view of a single node and its subtree, with links to any connected nodes.

Enums

Block
A descendant of a section, displayed as a block due to its layout or style.
Branch
A link to a node that “branches off” from the currently viewed node and is displayed before or after it.
Span
A descendant of a block, displayed as a span due to its layout or style.